prototype Block {
  /********************************************************************
    by Michael P. Bourque  10/31/97 1:00PM

    Function: Performs various functions against blocks of text:

    1. Fills or inserts a columnar block with a character or series of
       characters. Will prompt for a character sequence.

    2. Fills the marked blocks with text from the first or last line in
       the marked block.

    3. Enumerates the first occurrence of a number on each line of a marked
       block of text using values obtained from the first and second lines.
       If the first number is 20 then numbering continues upward from that
       number applying an increment based on the difference between the first
       and second numbers. For example, when the first line begins with 20
       and the next is 21 then subsequent lines are numbered 22, 23, 24,
       and so on. If the second line begins with 22, however, subsequent
       lines are numbered 24, 26, 28, and so on.

    4. Evaluates the selected area of text and determines what sensible
       fill concept to apply.

 ********************************************************************( mpb )***/

  void FillWhiteSpace( str PText );
  void _FillSeriesDlg( int Start_Value,
                           Increment,
                           Places,
                           Flags );
  void _FillSeriesEng( int Start_Value,
                           Increment,
                           Places,
                           Flags );
   int _FillBlockInsert( str PText, int Flags );
   int FillSeries( int Flags );
   int FillBlock( int Flags );
   int FillDown( int Flags );
   int FillUp( int Flags );
   int FillParagraph( int Style );
   int ConvertBlock( int Flags );
   int _FillEng( Str PText );
   int _ConvertBlockDlg( int Flags );
   int Convert_HexStr( str Hex );
   str _GetVal( int line );
   str _Leading( int value,
                     places );

}

#define Fill_title_ctrl            "FillSeries"
#define ConvertBlock_title_ctrl    "Convert Block?"
#define BlockFill_title_ctrl       "BlockFill"
#define Message1                   "Invalid block, or nothing to modify."
#define Message2                   "FillSeries found nothing to modify or was aborted by the user."
#define Message3                   "Stream blocks not allowed."
#define Message4                   "FillDown was performed."
#define Message5                   "FillSeries was performed."
#define Message6                   "FillUp was performed."
#define Message7                   "FillClear was performed."
#define Message8                   "Columnar block not marked."
#define Message9                   "SmartFill detects that the block is already enumerated. Invoke again to FillDown"
#define Message10                  "BlockFill was performed."
#define _g_FLSRDlgPos              "FLSRDlgPos"
#define _g_BFLDlgPos               "BFLDlgPos"
#define _g_CVDlgPos                "CVDlgPos"

#define _NoDlg                      0x0002
#define _NoMsg                      0x0004
#define _Cont                       0x0008
#define _OnlyInBlock                0x0010
#define _NoCol                      0x0020
#define _NoLine                     0x0040
#define _ForceOntoBlock             0x0080
#define _SkipOverEmpty              0x0100
#define _UseHexEquiv                0x0200
#define _RepHexEquiv                0x0400
#define _LCase                      0x0800
#define _InsertMode                 0x1000
#define _SkipMode                   0x0800  // temporary

#define OK_ctrl                     100
#define Cancel_ctrl                 110
#define Help_ctrl                   120

#define SmartFill_bitmap            1000  // needs to have its own bitmap
#define BlockFill_bitmap            1010  // needs to have its own bitmap
#define ConvertBlock_bitmap         1020  // needs to have its own bitmap
#define StartValue_title_ctrl       1030
#define StartValue_ctrl             1040
#define Increment_title_ctrl        1050
#define Increment_ctrl              1060
#define PreserveLeadingZeros_ctrl   1070
#define LowerCase_ctrl              1080
#define DontAskMeAgain_ctrl         1090
#define AllowOnlyInBlock_ctrl       1100
#define ForceValuesOntoBlock_ctrl   1110
#define EnterCharacter_title_ctrl   1120
#define FillEntireBlock_ctrl        1130
#define BlockFilltext_ctrl          1140
#define Convert_title_ctrl          1150
#define Column_ctrl                 1160
#define line_ctrl                   1170
#define FillWhiteSpaceOnly_ctrl     1180
#define SkipOverEmptyValues_ctrl    1190
#define InsertTextAtStartCol_ctrl   1200
#define Advanced_ctrl               1210
#define Advanced_title_ctrl         1220
#define Delimeter_title_ctrl        1230
#define UseHexEquivalents_ctrl      1240
#define GroupBox_title_ctrl         1250
#define HexIdentity_ctrl            1260
#define InsertMode_ctrl             1260
#define SkipEmptyLines_ctrl         1270

global
{
  int _g_BLKDntAsk   "BLKDntAsk";
  int _g_SFUHex      "SFUHex";
//  int _g_SFUHId      "SFUHId";
}
