/******************************************************************************
														 Multi-Edit Macro File
															 09-Jul-97  14:21

	Function: Interface definitions for MewScc32 DLL.
	Author  : Dan Hughes

	$Header: /MeWin32/SH/MEWSCC32.SH 5     4/02/98 4:42p Dan $

							 Copyright (C) 1997 by American Cybernectics, Inc.
 *******************************************************************( ldh )***/

/****************************************************************************
	Typedef constants
****************************************************************************/
#define HWnd				int

#define Bool				int
#define LpBool			*int
#define Long				DWord
#define SccRtn			Long
#define LpCStr			Asciiz
#define LpStr				*Asciiz
#define LpLong			*DWord
#define LpCmdOpts   Pointer


/****************************************************************************
  Version Flag.  Major is HIWORD, Minor is LOWORD
****************************************************************************/
#define scc_Major_Ver_Val   1
#define scc_Minor_Ver_Val   0


/****************************************************************************
  Following strings are the keys for accessing the registry to find the SCC
	provider.
 ***************************************************************************/
#define str_Scc_Provider_Reg_Location   "Software\\SourceCodeControlProvider"
#define str_Providerregkey              "ProviderRegKey"
#define str_Sccproviderpath             "SCCServerPath"
#define str_Sccprovidername             "SCCServerName"
#define str_Scc_Ini_Section             "Source Code Control"
#define str_Scc_Ini_Key                 "SourceCodeControlProvider"
#define scc_ProjectName_Key             "SCC_Project_Name"
#define scc_ProjectAux_Key              "SCC_Aux_Path"
#define scc_Status_File                 "MSSCCPRJ.SCC"
#define scc_Key                         "SCC"
#define scc_File_Signature              "This is a source code control file"


/****************************************************************************
  String lengths (each length does *not* include the terminating '\0')
 ***************************************************************************/
#define scc_Name_Len            31      // lpSccName, SCCInitialize
#define scc_Auxlabel_Len        31      // lpAuxPathLabel, SCCInitialize
#define scc_User_Len            31      // lpUser, SCCOpenProject
#define scc_PrjPath_Len         300     // lpAuxProjPath, SCCGetProjPath


/****************************************************************************
  These are the error codes that may be returned from a function. All errors
	are < 0, warnings are > 0, and success is 0.  Use the macros provided for
	quick checking.
 ***************************************************************************/
//	#define IS_SCC_ERROR(rtn) (((rtn) < 0) ? TRUE : FALSE)
//	#define IS_SCC_SUCCESS(rtn) (((rtn) == SCC_OK) ? TRUE : FALSE)
//	#define IS_SCC_WARNING(rtn) (((rtn) > 0) ? TRUE : FALSE)

#define scc_i_FileDiffers							6
#define scc_i_ReloadFile							5
#define scc_i_FileNotAffected         4
#define scc_i_ProjectCreated          3
#define scc_i_OperationCanceled       2
#define scc_i_Adv_Support             1

#define scc_Ok                        0

#define scc_e_InitializeFailed        -1
#define scc_e_UnknownProject          -2
#define scc_e_CouldNotCreateProject		-3
#define scc_e_NotCheckedOut           -4
#define scc_e_AlreadyCheckedOut       -5
#define scc_e_FileIsLocked            -6
#define scc_e_FileOutExclusive        -7
#define scc_e_AccessFailure           -8
#define scc_e_CheckinConflict         -9
#define scc_e_FileAlreadyExists       -10
#define scc_e_FileNotControlled       -11
#define scc_e_FileIsCheckedOut        -12
#define scc_e_NoSpecifiedVersion      -13
#define scc_e_OpNotSupported          -14
#define scc_e_NonSpecificError        -15
#define scc_e_OpNotPerformed          -16
#define scc_e_TypeNotSupported        -17
#define scc_e_VerifyMerge             -18
#define scc_e_FixMerge                -19
#define scc_e_ShellFailure            -20
#define scc_e_InvalidUser             -21
#define scc_e_ProjectAlreadyOpen      -22
#define scc_e_ProjSyntaxErr           -23
#define scc_e_InvalidFilePath         -24
#define scc_e_ProjNotOpen             -25
#define scc_e_NotAuthorized           -26
#define scc_e_FileSyntaxErr           -27
#define scc_e_FileNotExist            -28


/****************************************************************************
  The SCC_STATUS_xxx macros define the state of a file
 ***************************************************************************/
#define scc_status_Invalid        -1			// Status could not be obtained, don't rely on it
#define scc_status_NotControlled	0x0000	// File is not under source control
#define scc_status_Controlled     0x0001	// File is under source code control
#define scc_status_CheckedOut     0x0002	// Checked out to current user at local path
#define scc_status_OutOther       0x0004	// File is checked out to another user
#define scc_status_OutExclusive		0x0008	// File is exclusively check out
#define scc_status_OutMultiple    0x0010	// File is checked out to multiple people
#define scc_status_OutOfDate      0x0020	// The file is not the most recent
#define scc_status_Deleted        0x0040	// File has been deleted from the project
#define scc_status_Locked         0x0080	// No more versions allowed
#define scc_status_Merged         0x0100	// File has been merged but not yet fixed/verified
#define scc_status_Shared         0x0200	// File is shared between projects
#define scc_status_Pinned         0x0400	// File is shared to an explicit version
#define scc_status_Modified       0x0800	// File has been modified/broken/violated
#define scc_status_OutByUser			0x1000	// File is checked out by current user someplace


/****************************************************************************
  MewSccOpenProject flags
 ***************************************************************************/
#define scc_op_CreateIfNew      0x00000001
#define scc_op_SilentOpen       0x00000002


/****************************************************************************
  Keep checked out
 ***************************************************************************/
#define scc_keep_Checkedout     0x1000


/****************************************************************************
  Add flags
****************************************************************************/
#define scc_FileType_Auto       0x00
#define scc_FileType_Text       0x01
#define scc_FileType_Binary     0x02
#define scc_Add_StoreLatest     0x04


/****************************************************************************
  Diff flags.  The SCC_DIFF_QD_xxx flags are mutually exclusive.  If any one
	of the three are specified, then no visual feed back is to be given. If one
	is specified but not supported, then the next best one is chosen.
 ***************************************************************************/
#define scc_diff_IgnoreCase     0x0002
#define scc_diff_IgnoreSpace    0x0004
#define scc_diff_Qd_Contents		0x0010
#define scc_diff_Qd_Checksum		0x0020
#define scc_diff_Qd_Time				0x0040
#define scc_diff_Quick_Diff			0x0070		/* Any QD means no display     */


/****************************************************************************
  Remove flags
 ***************************************************************************/
#define scc_remove_Keep         0x00
#define scc_remove_Delete       0x01


/****************************************************************************
  Get flags
 ***************************************************************************/
#define scc_get_All             0x00000001
#define scc_get_Recursive       0x00000002


/****************************************************************************
  PopulateList flags
 ***************************************************************************/
#define scc_pl_Dir				0x00000001


/****************************************************************************
  Options for MewSccGetCommandOptions and MewSccPopulateList
 ***************************************************************************/
#define scc_command_Get				  0
#define scc_command_Checkout   	1
#define scc_command_Checkin    	2
#define scc_command_Uncheckout	3
#define scc_command_Add         4
#define scc_command_Remove      5
#define scc_command_Diff        6
#define scc_command_History     7
#define scc_command_Rename      8
#define scc_command_Properties  9
#define scc_command_Options     10


/****************************************************************************
  The SCC_CAP_xxx flags are used to determine what capabilites a provider
  has.
 ***************************************************************************/
#define scc_cap_Remove            0x00000001	// Supports the SCC_Remove command
#define scc_cap_Rename            0x00000002  // Supports the SCC_Rename command
#define scc_cap_Diff              0x00000004  // Supports the SCC_Diff command
#define scc_cap_History           0x00000008  // Supports the SCC_History command
#define scc_cap_Properties        0x00000010  // Supports the SCC_Properties command
#define scc_cap_RunScc            0x00000020  // Supports the SCC_RunScc command
#define scc_cap_GetCommandOptions 0x00000040  // Supports the SCC_GetCommandOptions command
#define scc_cap_QueryInfo         0x00000080  // Supports the SCC_QueryInfo command
#define scc_cap_GetEvents         0x00000100  // Supports the SCC_GetEvents command
#define scc_cap_GetProjPath       0x00000200  // Supports the SCC_GetProjPath command
#define scc_cap_AddFromScc        0x00000400  // Supports the SCC_AddFromScc command
#define scc_cap_CommentCheckout   0x00000800  // Supports a comment on Checkout
#define scc_cap_CommentCheckin    0x00001000  // Supports a comment on Checkin
#define scc_cap_CommentAdd        0x00002000  // Supports a comment on Add
#define scc_cap_CommentRemove     0x00004000  // Supports a comment on Remove
#define scc_cap_TextOut           0x00008000  // Writes text to an IDE-provided output function
#define scc_cap_Add_StoreLatest   0x00200000  // Supports storing files without deltas
#define scc_cap_History_Multfile  0x00400000  // Multiple file history is supported
#define scc_cap_IgnoreCase        0x00800000  // Supports case insensitive file comparison
#define scc_cap_IgnoreSpace       0x01000000  // Supports file comparison that ignores white space
#define scc_cap_PopulateList      0x02000000  // Supports finding extra files
#define scc_cap_CommentProject    0x04000000  // Supports comments on create project
#define scc_cap_Remove_Keep       0x08000000  // Supports option to keep/delete local file on Remove
#define scc_cap_DiffAlways        0x10000000  // Supports diff in all states if under control
#define scc_cap_Get_NoUI          0x20000000	// Provider doesn't support a UI for SccGet,
																							//   but IDE may still call SccGet function.


/****************************************************************************
  Following are the ASCII definitions of the functions.
 ***************************************************************************/
import void MewSccGetServerDll( LpStr ServerDll )
		MewScc32 'MewSccGetServerDll';

import int MewSccGetServerLst(
		LpStr ServerName,
		LpStr ServerDll,
		int		Index
		) MewScc32 'MewSccGetServerLst';

import int MewSccGetDbLst(
    LpStr DbName,
    LpStr DbPath,
		int		Index
    ) MewScc32 'MewSccGetDbLst';

import int MewSccAddFile( LpCStr FileName )
		MewScc32 'MewSccAddFile';

import int MewSccAddFileFlags( LpCStr FileName, int Flags )
		MewScc32 'MewSccAddFileFlags';

import void	MewSccGetFile( LpStr FileName, Long Index )
		MewScc32 'MewSccGetFile';

import void	MewSccClrFiles( )
		MewScc32 'MewSccClrFiles';

import int MewSccFileCount( )
		MewScc32 'MewSccFileCount';

/* -----------------10-22-1996 17:16-----------------

	--------------------------------------------------*/
import Bool	MewSccLoadServer( LPSTR szServer )
		MewScc32 "MewSccLoadServer";

/* -----------------10-22-1996 17:16-----------------

	--------------------------------------------------*/
import void	MewSccUnloadServer( )
		MewScc32 "MewSccUnloadServer";

/****************************************************************************
	Returns a 4 byte version of the provider.  This can be used to check for
	SCC spec conformance.
 ***************************************************************************/
import Long	MewSccGetVersion( )
		MewScc32 "MewSccGetVersion";

/****************************************************************************
	Call this function once per instance of a provider.
 ***************************************************************************/
import SccRtn	MewSccInitialize(
		HWnd 		hWnd,
		LPCSTR	lpCallerName,
		LPSTR		lpSccName,
		LPLONG	lpSccCaps,
		LPSTR 	lpAuxPathLabel,
		LPLONG	pnCheckoutCommentLen,
		LPLONG	pnCommentLen
		)	MewScc32 "MewSccInitialize";

/****************************************************************************
	Call this function once for every instance of a provider, when it is going
	away.  You must call MewSccInitialize before calling this function, and
	should not call it with any open projects.
 ***************************************************************************/
import SccRtn	MewSccUninitialize( )
		MewScc32 "MewSccUninitialize";

/****************************************************************************
	Opens a project.  This function should never be called with an already open
	project.  The lpUser, lpProjName, and lpAuxProjPath values may be modified
	by the provider.
 ***************************************************************************/
import SccRtn	MewSccOpenProject(
		HWND		hWnd,
    LPSTR		lpUser,
    LPSTR		lpProjName,
    LPCSTR 	lpLocalProjPath,
    LPSTR 	lpAuxProjPath,
    LPCSTR	lpComment,
    LONG 		dwFlags
    )	MewScc32 "MewSccOpenProject";

/****************************************************************************
	Called to close a project opened by MewSccOpenProject.
 ***************************************************************************/
import SccRtn	MewSccCloseProject( )
		MewScc32 "MewSccCloseProject";

/****************************************************************************
	Prompts the user for provider project information.  This may include the
	path to a certain project.  The caller must be prepared to accept changes
	to lpUser, lpProjName, lpLocalPath, and lpAuxProjPath.  lpProjName and
	lpAuxProjPath are then used in a call to MewSccOpenProject.  They should
	not be modified by the caller upon return.  The caller should avoid
	displaying these two parameters upon return, as the provider might use a
	formatted string that is not ready for view.
 ***************************************************************************/
import SccRtn	MewSccGetProjPath(
		HWND 		hWnd,
    LPSTR 	lpUser,
    LPSTR 	lpProjName,
    LPSTR 	lpLocalPath,
    LPSTR 	lpAuxProjPath,
    BOOL 		bAllowChangePath,
    LPBOOL	pbNew
    )	MewScc32 "MewSccGetProjPath";

/* -----------------10-22-1996 17:16-----------------

	--------------------------------------------------*/
import SccRtn	MewSccGet(
		HWND 				hWnd,
		LONG				dwFlags,
		LPCMDOPTS		pvOptions
		)	MewScc32 "MewSccGet";

/* -----------------10-22-1996 17:16-----------------

	--------------------------------------------------*/
import SccRtn	MewSccCheckout(
		HWND 				hWnd,
		LPCSTR			lpComment,
		LONG				dwFlags,
		LPCMDOPTS		pvOptions
		)	MewScc32 "MewSccCheckout";

/* -----------------10-22-1996 17:16-----------------

	--------------------------------------------------*/
import SccRtn	MewSccUncheckout(
		HWND				hWnd,
		LONG				dwFlags,
		LPCMDOPTS 	pvOptions
		) MewScc32 "MewSccUncheckout";

/* -----------------10-22-1996 17:16-----------------

	--------------------------------------------------*/
import SccRtn	MewSccCheckin(
		HWND				hWnd,
		LPCSTR			lpComment,
		LONG				dwFlags,
		LPCMDOPTS		pvOptions
    )	MewScc32 "MewSccCheckin";

/* -----------------10-22-1996 17:16-----------------

	--------------------------------------------------*/
import SccRtn	MewSccAdd(
		HWND 				hWnd,
		LPCSTR			lpComment,
		LPCMDOPTS		pvOptions
		)	MewScc32 "MewSccAdd";

/* -----------------10-22-1996 17:16-----------------

	--------------------------------------------------*/
import SccRtn	MewSccRemove(
		HWND 				hWnd,
		LPCSTR			lpComment,
		LONG				dwFlags,
		LPCMDOPTS 	pvOptions
		)	MewScc32 "MewSccRemove";

/* -----------------10-22-1996 17:16-----------------

	--------------------------------------------------*/
import SccRtn	MewSccRename(
		HWND 				hWnd,
    LPCSTR 			lpFileName,
    LPCSTR 			lpNewName
    )	MewScc32 "MewSccRename";

/* -----------------10-22-1996 17:16-----------------

	--------------------------------------------------*/
import SccRtn MewSccDiff(
		HWND 				hWnd,
    LPCSTR 			lpFileName,
    LONG 				dwFlags,
 		LPCMDOPTS 	pvOptions
    )	MewScc32 "MewSccDiff";

/* -----------------10-22-1996 17:17-----------------

	--------------------------------------------------*/
import SccRtn	MewSccHistory(
		HWnd 				Wnd,
		Long 				Flags,
		LpCmdOpts		Options
		)	MewScc32 "MewSccHistory";


import SccRtn	MewSccProperties( HWnd Wnd, LpCStr FileName )
		MewScc32 "MewSccProperties";

/* -----------------10-22-1996 17:17-----------------

	--------------------------------------------------*/
import SccRtn	MewSccQueryInfo( LpLong Status, int Index )
		MewScc32 "MewSccQueryInfo";

/* -----------------10-22-1996 17:17-----------------

	--------------------------------------------------*/
import SccRtn	MewSccRunScc( HWnd HWnd )
		MewScc32 "MewSccRunScc";

import SccRtn MewSccGetCommandOptions(
		HWnd			Wnd,
		int				Command,
		Pointer		Options
		) MewScc32 'MewSccGetCommandOptions';
