// General
#define ODT_HEADER              100
#define ODT_TAB                 101
#define ODT_LISTVIEW            102


//====== Ranges for control message IDs =======================================

#define LVM_FIRST               0x1000      // ListView messages
#define TV_FIRST                0x1100      // TreeView messages
#define HDM_FIRST               0x1200      // Header messages

//====== Generic WM_NOTIFY notification codes =================================

#define NM_OUTOFMEMORY          (NM_FIRST-1)
#define NM_CLICK                (NM_FIRST-2)
#define NM_DBLCLK               (NM_FIRST-3)
#define NM_RETURN               (NM_FIRST-4)
#define NM_RCLICK               (NM_FIRST-5)
#define NM_RDBLCLK              (NM_FIRST-6)
#define NM_SETFOCUS             (NM_FIRST-7)
#define NM_KILLFOCUS            (NM_FIRST-8)


//====== WM_NOTIFY codes (NMHDR.code values) ==================================

#define NM_FIRST                (0-  0)       // generic to all controls
#define NM_LAST                 (0- 99)

#define LVN_FIRST               (0-100)       // listview
#define LVN_LAST                (0-199)

#define HDN_FIRST               (0-300)       // header
#define HDN_LAST                (0-399)

#define TVN_FIRST               (0-400)       // treeview
#define TVN_LAST                (0-499)

#define TTN_FIRST               (0-520)       // tooltips
#define TTN_LAST                (0-549)

#define TCN_FIRST               (0-550)       // tab control
#define TCN_LAST                (0-580)

// Shell reserved               (0-580) -  (0-589)

#define CDN_FIRST               (0-601)       // common dialog (new)
#define CDN_LAST                (0-699)

#define TBN_FIRST               (0-700)       // toolbar
#define TBN_LAST                (0-720)

#define UDN_FIRST               (0-721)        // updown
#define UDN_LAST                (0-740)

#define MSGF_COMMCTRL_BEGINDRAG     0x4200
#define MSGF_COMMCTRL_SIZEHEADER    0x4201
#define MSGF_COMMCTRL_DRAGSELECT    0x4202
#define MSGF_COMMCTRL_TOOLBARCUST   0x4203




//====== TAB CONTROL ==========================================================

#define WC_TABCONTROL          "SysTabControl32"

#define TCS_SCROLLOPPOSITE      0x0001;
#define TCS_BOTTOM              0x0002;
#define TCS_RIGHT               0x0002;
#define TCS_FORCEICONLEFT       0x0010
#define TCS_FORCELABELLEFT      0x0020
#define TCS_VERTICAL            0x0080;
#define TCS_TABS                0x0000
#define TCS_BUTTONS             0x0100
#define TCS_SINGLELINE          0x0000
#define TCS_MULTILINE           0x0200
#define TCS_RIGHTJUSTIFY        0x0000
#define TCS_FIXEDWIDTH          0x0400
#define TCS_RAGGEDRIGHT         0x0800
#define TCS_FOCUSONBUTTONDOWN   0x1000
#define TCS_OWNERDRAWFIXED      0x2000
#define TCS_TOOLTIPS            0x4000
#define TCS_FOCUSNEVER          0x8000


#define TCM_FIRST               0x1300





#define TCM_GETIMAGELIST        (TCM_FIRST + 2)
#define TCM_SETIMAGELIST        (TCM_FIRST + 3)
#define TCM_GETITEMCOUNT        (TCM_FIRST + 4)

#define TCIF_TEXT               0x0001
#define TCIF_IMAGE              0x0002
#define TCIF_RTLREADING         0x0004
#define TCIF_PARAM              0x0008

#define uint int
#define lpstr int

structure TC_ITEMHEADER
{
    UINT mask;
    UINT lpReserved1;
    UINT lpReserved2;
    LPSTR pszText;
    int cchTextMax;
    int iImage;
};

structure TC_ITEM
{
    UINT mask;
    UINT lpReserved1;
    UINT lpReserved2;
    LPSTR pszText;
    int cchTextMax;
    int iImage;

    int lParam;
};
#define TCM_GETITEM            (TCM_FIRST + 5)
#define TCM_SETITEM            (TCM_FIRST + 6)
#define TCM_INSERTITEM         (TCM_FIRST + 7)
#define TCM_DELETEITEM         (TCM_FIRST + 8)
#define TCM_DELETEALLITEMS      (TCM_FIRST + 9)
#define TCM_GETITEMRECT         (TCM_FIRST + 10)
#define TCM_GETCURSEL           (TCM_FIRST + 11)
#define TCM_SETCURSEL           (TCM_FIRST + 12)
#define TCHT_NOWHERE            0x0001
#define TCHT_ONITEMICON         0x0002
#define TCHT_ONITEMLABEL        0x0004
#define TCHT_ONITEM             (TCHT_ONITEMICON | TCHT_ONITEMLABEL)

structure TC_HITTESTINFO
{
    int x;
		int y;
    UINT flags;
};


#define TCM_HITTEST             (TCM_FIRST + 13)
#define TCM_SETITEMEXTRA        (TCM_FIRST + 14)
#define TCM_ADJUSTRECT          (TCM_FIRST + 40)
#define TCM_SETITEMSIZE         (TCM_FIRST + 41)
#define TCM_REMOVEIMAGE         (TCM_FIRST + 42)
#define TCM_SETPADDING          (TCM_FIRST + 43)
#define TCM_GETROWCOUNT         (TCM_FIRST + 44)
#define TCM_GETTOOLTIPS         (TCM_FIRST + 45)
#define TCM_SETTOOLTIPS         (TCM_FIRST + 46)
#define TCM_GETCURFOCUS         (TCM_FIRST + 47)
#define TCM_SETCURFOCUS         (TCM_FIRST + 48)
#define TCN_KEYDOWN             (TCN_FIRST - 0)
//structure TC_KEYDOWN
//{
//    NMHDR hdr;
//    WORD wVKey;
//    UINT flags;
//};

#define TCN_SELCHANGE           (TCN_FIRST - 1)
#define TCN_SELCHANGING         (TCN_FIRST - 2)



// Up-Down control stuff

#define UD_MAXVAL               0x7fff
#define UD_MINVAL               (-UD_MAXVAL)


#define UDS_WRAP                0x0001
#define UDS_SETBUDDYINT         0x0002
#define UDS_ALIGNRIGHT          0x0004
#define UDS_ALIGNLEFT           0x0008
#define UDS_AUTOBUDDY           0x0010
#define UDS_ARROWKEYS           0x0020
#define UDS_HORZ                0x0040
#define UDS_NOTHOUSANDS         0x0080


#define UDM_SETRANGE            (WM_USER+101)
#define UDM_GETRANGE            (WM_USER+102)
#define UDM_SETPOS              (WM_USER+103)
#define UDM_GETPOS              (WM_USER+104)
#define UDM_SETBUDDY            (WM_USER+105)
#define UDM_GETBUDDY            (WM_USER+106)
#define UDM_SETACCEL            (WM_USER+107)
#define UDM_GETACCEL            (WM_USER+108)
#define UDM_SETBASE             (WM_USER+109)
#define UDM_GETBASE             (WM_USER+110)

// These are new, version 4.71
#define UDM_SETRANGE32          (WM_USER+111)
#define UDM_GETRANGE32          (WM_USER+112) // wParam & lParam are LPINT


import dword CreateUpDownControl  (
    DWORD dwStyle,
    int x, int y, int cx, int cy,
    HWND hParent,
    int nID,
    dword hInst,
    HWND hBuddy,
    int nUpper, int nLower, int nPos
    ) comctl32 "CreateUpDownControl";

//====== TREEVIEW CONTROL =====================================================

#define TVS_HASBUTTONS          0x0001
#define TVS_HASLINES            0x0002
#define TVS_LINESATROOT         0x0004
#define TVS_EDITLABELS          0x0008
#define TVS_DISABLEDRAGDROP     0x0010
#define TVS_SHOWSELALWAYS       0x0020

#define HTREEITEM  int

#define TVIF_TEXT               0x0001
#define TVIF_IMAGE              0x0002
#define TVIF_PARAM              0x0004
#define TVIF_STATE              0x0008
#define TVIF_HANDLE             0x0010
#define TVIF_SELECTEDIMAGE      0x0020
#define TVIF_CHILDREN           0x0040

#define TVIS_FOCUSED            0x0001
#define TVIS_SELECTED           0x0002
#define TVIS_CUT                0x0004
#define TVIS_DROPHILITED        0x0008
#define TVIS_BOLD               0x0010
#define TVIS_EXPANDED           0x0020
#define TVIS_EXPANDEDONCE       0x0040

#define TVIS_OVERLAYMASK        0x0F00
#define TVIS_STATEIMAGEMASK     0xF000
#define TVIS_USERMASK           0xF000


#define I_CHILDRENCALLBACK  (-1)

struct TTVITEM
{
    UINT      mask;
    HTREEITEM hItem;
    UINT      state;
    UINT      stateMask;
    int       pszText;
    int       cchTextMax;
    int       iImage;
    int       iSelectedImage;
    int       cChildren;
    int       lParam;
}

#define TVI_ROOT                (0xFFFF0000)
#define TVI_FIRST               (0xFFFF0001)
#define TVI_LAST                (0xFFFF0002)
#define TVI_SORT                (0xFFFF0003)

struct TTVINSERTSTRUCT {
    HTREEITEM hParent;
    HTREEITEM hInsertAfter;
//    TV_ITEM item;
    UINT      mask;
    HTREEITEM hItem;
    UINT      state;
    UINT      stateMask;
    ASCIIZ    pszText;
    int       cchTextMax;
    int       iImage;
    int       iSelectedImage;
    int       cChildren;
    int       lParam;
}

#define TVM_INSERTITEM         (TV_FIRST + 0)
#define TVM_DELETEITEM         (TV_FIRST + 1)
#define TVM_EXPAND             (TV_FIRST + 2)

#define TVE_COLLAPSE            0x0001
#define TVE_EXPAND              0x0002
#define TVE_TOGGLE              0x0003
#define TVE_COLLAPSERESET       0x8000


#define TVM_GETITEMRECT         (TV_FIRST + 4)
#define TVM_GETCOUNT            (TV_FIRST + 5)
#define TVM_GETINDENT           (TV_FIRST + 6)
#define TVM_SETINDENT           (TV_FIRST + 7)
#define TVM_GETIMAGELIST        (TV_FIRST + 8)

#define TVSIL_NORMAL            0
#define TVSIL_STATE             2


#define TVM_SETIMAGELIST        (TV_FIRST + 9)
#define TVM_GETNEXTITEM         (TV_FIRST + 10)

#define TVGN_ROOT               0x0000
#define TVGN_NEXT               0x0001
#define TVGN_PREVIOUS           0x0002
#define TVGN_PARENT             0x0003
#define TVGN_CHILD              0x0004
#define TVGN_FIRSTVISIBLE       0x0005
#define TVGN_NEXTVISIBLE        0x0006
#define TVGN_PREVIOUSVISIBLE    0x0007
#define TVGN_DROPHILITE         0x0008
#define TVGN_CARET              0x0009

#define TVM_SELECTITEM          (TV_FIRST + 11)
#define TVM_GETITEM             (TV_FIRST + 12)
#define TVM_SETITEM             (TV_FIRST + 13)
#define TVM_EDITLABEL           (TV_FIRST + 14)
#define TVM_GETEDITCONTROL      (TV_FIRST + 15)
#define TVM_GETVISIBLECOUNT     (TV_FIRST + 16)
#define TVM_HITTEST             (TV_FIRST + 17)

struct TTVHITTESTINFO {
    //POINT       pt;
    int         pt_x;
    int         pt_y;

    UINT        flags;
    HTREEITEM   hItem;
}

#define TVHT_NOWHERE            0x0001
#define TVHT_ONITEMICON         0x0002
#define TVHT_ONITEMLABEL        0x0004
#define TVHT_ONITEM             (TVHT_ONITEMICON | TVHT_ONITEMLABEL | TVHT_ONITEMSTATEICON)
#define TVHT_ONITEMINDENT       0x0008
#define TVHT_ONITEMBUTTON       0x0010
#define TVHT_ONITEMRIGHT        0x0020
#define TVHT_ONITEMSTATEICON    0x0040

#define TVHT_ABOVE              0x0100
#define TVHT_BELOW              0x0200
#define TVHT_TORIGHT            0x0400
#define TVHT_TOLEFT             0x0800


#define TVM_CREATEDRAGIMAGE     (TV_FIRST + 18)
#define TVM_SORTCHILDREN        (TV_FIRST + 19)
#define TVM_ENSUREVISIBLE       (TV_FIRST + 20)
#define TVM_SORTCHILDRENCB      (TV_FIRST + 21)
#define TVM_ENDEDITLABELNOW     (TV_FIRST + 22)
#define TVM_GETISEARCHSTRING    (TV_FIRST + 23)
//struct TTVSORTCB
//{
//        HTREEITEM       hParent;
//        PFNTVCOMPARE    lpfnCompare;
//        LPARAM          lParam;
//}



//====== IMAGE APIS ===========================================================

#define CLR_NONE                0xFFFFFFFFL
#define CLR_DEFAULT             0xFF000000L

structure _IMAGELIST
{
    int dummy;      /* used to prevent undefined structure warnings */
}

#define HIMAGELIST int

#define ILC_MASK                0x0001
#define ILC_COLOR               0x0000
#define ILC_COLORDDB            0x00FE
#define ILC_COLOR4              0x0004
#define ILC_COLOR8              0x0008
#define ILC_COLOR16             0x0010
#define ILC_COLOR24             0x0018
#define ILC_COLOR32             0x0020
#define ILC_PALETTE             0x0800

import HIMAGELIST ImageList_Create(int cx, int cy, UINT flags, int cInitial, int cGrow) comctl32 "ImageList_Create";
import BOOL        ImageList_Destroy(HIMAGELIST himl) comctl32 "ImageList_Destroy";
import int         ImageList_GetImageCount(HIMAGELIST himl) comctl32 "ImageList_GetImageCount";
import int         ImageList_Add(HIMAGELIST himl, HBITMAP hbmImage, HBITMAP hbmMask) comctl32 "ImageList_Add";
import int         ImageList_AddMasked(HIMAGELIST himl, HBITMAP hbmImage, int c) comctl32 "ImageList_AddMasked";
import TCOLORREF    ImageList_SetBkColor(HIMAGELIST himl, TCOLORREF clrBk)  comctl32 "ImageList_SetBkColor";

#define ILD_NORMAL              0x0000
#define ILD_TRANSPARENT         0x0001
#define ILD_MASK                0x0010
#define ILD_IMAGE               0x0020
#define ILD_BLEND25             0x0002
#define ILD_BLEND50             0x0004
#define ILD_OVERLAYMASK         0x0F00
#define INDEXTOOVERLAYMASK(i)   ((i) << 8)

#define ILD_SELECTED            ILD_BLEND50
#define ILD_FOCUS               ILD_BLEND25
#define ILD_BLEND               ILD_BLEND50
#define CLR_HILIGHT             CLR_DEFAULT

