// $Header: /Me8/SH/LANGUAGE.SH 6     1/29/99 4:09p Dan $

// Header file for Language

// GetStatusAtCursor constants
#define _gsac_BlkCmt1       0x0001 // Cursor is in Open/Close comment 1
#define _gsac_BlkCmt2       0x0002 // Cursor is in Open/Close comment 2
#define _gsac_EolCmt1        0x0004 // Cursor is in EOL comment 1
#define _gsac_EolCmt2        0x0008 // Cursor is in EOL comment 2
#define _gsac_String         0x0010 // Cursor is in a quoted string
#define _gsac_EolCmt3        0x0040 // In an end of line comment 3
#define _gsac_EolCmt4        0x0080 // In an end of line comment 4
#define _gsac_KEYWORD        0x0700 // Cursor is in any keyword
#define _gsac_KEYWORD1       0x0100 // Cursor is in a keyword contained in keywords1
#define _gsac_KEYWORD2       0x0200 // Cursor is in a keyword contained in keywords2
#define _gsac_KEYWORD3       0x0300 // Cursor is in a keyword contained in keywords3
#define _gsac_KEYWORD4       0x0400 // Cursor is in a keyword contained in keywords4
#define _gsac_SYMBOL         0x0800 // Cursor is on a symbol
#define _gsac_NUMERIC        0x1000 // Cursor is in a number
#define _gsac_SecondLang     0x8000      // In a second language

#define _gsac_BlkComments    0x0003 // In any block comment
#define _gsac_EolComments    0x00CC // In any end of line comment
#define _gsac_Comments       0x00CF // In any kind of comment

#define _db_lang_Page				"LANGUAGE.DB"

// Language config field constants
#define _db_lang_Type				"LANG"
#define _db_lang_Case				"CS"
#define _db_lang_ResWord1		"RW1"
#define _db_lang_ResWord2		"RW2"
#define _db_lang_ResWord3		"RW3"
#define _db_lang_ResWord4		"RW4"
#define _db_lang_Symbols		"SYM"
#define _db_lang_Strings		"STR"
#define _db_lang_Numeric		"NC"
#define _db_lang_Literal		"LIT"
#define _db_lang_OpenCmt1		"OC1"
#define _db_lang_CloseCmt1	"CC1"
#define _db_lang_OpenCmt2		"OC2"
#define _db_lang_CloseCmt2	"CC2"
#define _db_lang_EolCmt1		"EOL"
#define _db_lang_EolCol1		"EOC"
#define _db_lang_EolCmt2		"EOL2"
#define _db_lang_EolCol2		"EOC2"
#define _db_lang_EolCmt3		"EOL3"
#define _db_lang_EolCol3		"EOC3"
#define _db_lang_EolCmt4		"EOL4"
#define _db_lang_EolCol4		"EOC4"
#define _db_lang_CfgMac			"CFGMAC"
#define _db_lang_InitMac		"INIMAC"
#define _db_lang_IndentMac	"INDMAC"
#define _db_lang_MatchMac		"MATMAC"
#define _db_lang_FindTagMac	"FTMAC"
#define _db_lang_Properties	"PROP"
#define _db_lang_TagFile		"TAGFILE"

// Language match construct delimiter constants
#define _mtchBeg    				"\x7F" + "B="
#define _mtchMid    				"\x7F" + "M="
#define _mtchEnd    				"\x7F" + "E="
#define _mtchExp    				"\x7F" + "X="
#define _mtchFlags					"\x7F" + "F="
#define _mtchIgnore         "\x7F" + "I="
#define _mtchCont						"\x7F" + "C="

#define _mtchBChars					"\x7F" + "B="
#define _mtchEChars 				"\x7F" + "E="
#define _mtchDelim					"\x7F" + "D="

// Match construct flags
#define _mcf_StrOnly          0x0001    // Do not use B/EChars in matching
#define _mcf_SkipMid          0x0002    // Skip the patterns in _mtchMid
#define _mcf_ContMatch        0x0004
#define _mcf_AcceptOnMatch    0x0008    // Accept on any match found

#define _langRecGlob				"!LR_"

#define languages_HelpLink  "LANGUAGES"
#define hc_Properties        "Properties, "

global {
  int g_LangInCmt   "!LangInCmt";
}
// Comment character structure
structure TCommentChars {
	str szOpenComment1[ 32 ];
	str szCloseComment1[ 32 ];
	str szOpenComment2[ 32 ];
	str szCloseComment2[ 32 ];
	str szEolComment1[ 32 ];
	str szEolComment2[ 32 ];
	str szEolComment3[ 32 ];
	str szEolComment4[ 32 ];

	int nEolColumn1;
	int nEolColumn2;
	int nEolColumn3;
	int nEolColumn4;
}

prototype Language {
	int LangGetRecord( str &Language, str &Record );
/******************************************************************************
	Function: Get the language config record for Language.

	Entry   : str Language	- The language to get the config data for.  If "" then
														use the file name specified in Record or the
														current file name to determine the language.

						str Record		- A variable used to return the record data.  When
														Language is "" Record can contain a file name to
														use to determine the language or "" to use current
														file name.

	Exit    : int
							_NoError					- Record found.
								Language					- The selected language name.
								Record						- The config data for Language.

							_ErrorNoDbRecord	- Error no record found.
								Language					- The selected language or "".
								Record						- "".
********************************************************************( ldh )***/

	int LangDoMatch( str LangPrefix, str MatchStr, str ParmStr );
/******************************************************************************
  Function: Find matching language constructs.

	Entry   : str LangPrefix	- The first three character of the language 	(/LP=)
						str MatchStr		- The string to match, if "" then find string (/MS=)
						str ParmStr			- Additional parameters
 							/HI=1    				- Highlight block
							/RC=1    				-	Restore cursor to original position
							/LS=x    				-	Limit scope of search to x number of lines
							/NM=1						- Display no messages
							/NA=1						- No check for abort
							/IC=1						- Starting match in comment
  															(Only used when MatchStr is passed)

	Exit    : Return_Int
						 -1					- Search aborted
							0         - Match found
							1         - No match found
********************************************************************( ldh )***/

  int Match( );
/******************************************************************************
	Function: Calls the matching macro defined for the language specified by
						the filename extension of the current file.  If no macro is defined,
						the macro name is determined by the first three characters of the
						language type followed by 'MTCH'. For example, the pascal matching
						macro would be named 'PASMTCH', the C macro would be 'CMTCH'
******************************************************************************/

	void LangCloseParen( str LangPrefix, str ParmStr );
/******************************************************************************
	Function: Auto match the opening paren for the specified language.

	Entry   : str LangPrefix	- The first three letters of the language (/LP=)
						str ParmStr			- Additional parameters 		 ( See LangDoMatch )
********************************************************************( ldh )***/

  void GetCommentChars( struct TCommentChars RCC );
/******************************************************************************
  Function: Fill the tCommentChars structure rCC with the comment chars for the
						language specified by the current file.

  Entry   : struct tCommentChars rCC	- Structure to contain comment chars
********************************************************************( ldh )***/

	void Comment( );
/******************************************************************************
  Function: Control function for comment support macros.  Autodetects whether
						to comment or uncomment a code block.
********************************************************************( ldh )***/

	void CommentCode( );
/******************************************************************************
  Function: Translates current block mark into a comment block
							If Block_Stat = 0,  current line using open,close comment string
															1,  current line using eol comment string
															2,  remainder of current line using eol string
															3,  start,end block mark with comment chars
********************************************************************( ldh )***/

	void UnCommentCode( );
/******************************************************************************
  Function: Translates current block mark to uncommented code block.
********************************************************************( ldh )***/
}
