/*++

Copyright (c) 1995-1996  Microsoft Corporation

Module Name:

    wininet.h

Abstract:

    Contains manifests, macros, types and prototypes for Microsoft Windows
    Internet Extensions

--*/

#ifndef _WININET_
#define _WININET_ 1


// Types from other Win32 stuff

// File System time stamps are represented with the following structure:

// The operation completed successfully.
#define ERROR_SUCCESS   0
#define NO_ERROR        0
// There are no more files.
#define ERROR_NO_MORE_FILES  18


struct TFileTime {
    INT   dwLowDateTime;
    INT   dwHighDateTime;
}
#define PFileTime Pointer

struct Win32_Find_DataA {
    INT   dwFileAttributes;
    // ftCreationTime: TFileTime;
    INT   ftCreationTime_Low;
    INT   ftCreationTime_High;
    // ftLastAccessTime: TFileTime;
    INT   ftLastAccessTime_Low;
    INT   ftLastAccessTime_High;
    // ftLastWriteTime: TFileTime;
    INT   ftLastWriteTime_Low;
    INT   ftLastWriteTime_High;

    INT   nFileSizeHigh;
    INT   nFileSizeLow;
    INT   dwReserved0;
    INT   dwReserved1;
    ASCIIZ cFileName [260];
    ASCIIZ cAlternateFileName[14];

		WORD  Filler;  //Fill to 4 byte boundry

}
#define LPWIN32_FIND_DATA Pointer

import DWORD GetLastError () KERNEL32 'GetLastError';

// file attribute constants
#define FILE_ATTRIBUTE_READONLY       0x00000001
#define FILE_ATTRIBUTE_HIDDEN         0x00000002
#define FILE_ATTRIBUTE_SYSTEM         0x00000004
#define FILE_ATTRIBUTE_DIRECTORY      0x00000010
#define FILE_ATTRIBUTE_ARCHIVE        0x00000020
#define FILE_ATTRIBUTE_NORMAL         0x00000080
#define FILE_ATTRIBUTE_TEMPORARY      0x00000100
#define FILE_ATTRIBUTE_ATOMICWRITE    0x00000200
#define FILE_ATTRIBUTE_XACTIONWRITE   0x00000400

//
// internet types
//

#define HINTERNET         DWORD
#define LPHINTERNET       DWORD

#define INTERNET_PORT     Word
#define LPINTERNET_PORT   *Word

//
// Internet APIs
//

//
// manifests
//

#define INTERNET_INVALID_PORT_NUMBER    0           // use the protocol-specific default

#define INTERNET_DEFAULT_FTP_PORT       21          // default for FTP servers
#define INTERNET_DEFAULT_GOPHER_PORT    70          //    "     "  gopher "
#define INTERNET_DEFAULT_HTTP_PORT      80          //    "     "  HTTP   "
#define INTERNET_DEFAULT_HTTPS_PORT     443         //    "     "  HTTPS  "
#define INTERNET_DEFAULT_SOCKS_PORT     1080        // default for SOCKS firewall servers.

#define MAX_CACHE_ENTRY_INFO_SIZE       4096

//
// maximum field lengths (arbitrary)
//

#define INTERNET_MAX_HOST_NAME_LENGTH   256
#define INTERNET_MAX_USER_NAME_LENGTH   128
#define INTERNET_MAX_PASSWORD_LENGTH    128
#define INTERNET_MAX_PORT_NUMBER_LENGTH 5           // INTERNET_PORT is unsigned short
#define INTERNET_MAX_PORT_NUMBER_VALUE  65535       // maximum unsigned short value
#define INTERNET_MAX_PATH_LENGTH        2048
#define INTERNET_MAX_PROTOCOL_NAME      "gopher"    // longest protocol name
#define INTERNET_MAX_URL_LENGTH         (5 + 3 + INTERNET_MAX_PATH_LENGTH)

//
// values returned by InternetQueryOption() with INTERNET_OPTION_KEEP_CONNECTION:
//

#define INTERNET_KEEP_ALIVE_UNKNOWN     3
#define INTERNET_KEEP_ALIVE_ENABLED     1
#define INTERNET_KEEP_ALIVE_DISABLED    0

//
// flags returned by InternetQueryOption() with INTERNET_OPTION_REQUEST_FLAGS
//

#define INTERNET_REQFLAG_FROM_CACHE     0x00000001
#define INTERNET_REQFLAG_ASYNC          0x00000002

//
// flags common to open functions (not InternetOpen()):
//

#define IFLAG_RELOAD            0x80000000  // retrieve the original item

//
// flags for InternetOpenUrl():
//

#define IFLAG_RAW_DATA          0x40000000  // receive the item as raw data
#define IFLAG_EXISTING_CONNECT  0x20000000  // do not create new connection object

//
// flags for InternetOpen():
//

#define IFLAG_ASYNC             0x10000000  // this request is asynchronous (where supported)

//
// protocol-specific flags:
//

#define IFLAG_PASSIVE           0x08000000  // used for FTP connections

//
// additional cache flags
//

#define IFLAG_NO_CACHE_WRITE    0x04000000  // don't write this item to the cache
#define IFLAG_DONT_CACHE        IFLAG_NO_CACHE_WRITE

#define IFLAG_MAKE_PERSISTENT   0x02000000  // make this item persistent in cache

#define IFLAG_OFFLINE           0x01000000  // use offline semantics

//
// additional flags
//

#define IFLAG_SECURE            0x00800000  // use PCT/SSL if applicable (HTTP)

#define IFLAG_KEEP_CONNECTION   0x00400000  // use keep-alive semantics

#define IFLAG_NO_AUTO_REDIRECT  0x00200000  // don't handle redirections automatically

#define IFLAG_READ_PREFETCH     0x00100000  // do background read prefetch

#define IFLAG_NO_COOKIES        0x00080000  // no automatic cookie handling

#define IFLAG_NO_AUTH           0x00040000  // no automatic authentication handling

//
// Security Ignore Flags, Allow HttpOpenRequest to overide
//  Secure Channel (SSL/PCT) failures of the following types.
//

#define IFLAG_IGNORE_REDIRECT_TO_HTTP   0x00008000 // ex: https:// to http://

#define IFLAG_IGNORE_REDIRECT_TO_HTTPS  0x00004000 // ex: http:// to https://

#define IFLAG_IGNORE_CERT_DATE_INVALID  0x00002000 // expired X509 Cert.

#define IFLAG_IGNORE_CERT_CN_INVALID    0x00001000 // bad common name in X509 Cert.

//more caching flags
#define IFLAG_MUST_CACHE_REQUEST        0x00000010 // fails if unable to cache request
#define IFLAG_RESYNCHRONIZE             0x00000800 // asking wininet to update an item if it is newer
#define IFLAG_HYPERLINK                 0x00000400 // asking wininet to
                                                           //do hyperlinking semantic which works right for scripts
#define IFLAG_NO_UI                     0x00000200

//
// flags for FTP
//

#define IFLAG_TRANSFER_ASCII    FTP_TRANSFER_TYPE_ASCII
#define IFLAG_TRANSFER_BINARY   FTP_TRANSFER_TYPE_BINARY

//
// flags field masks
//

#define SECURITY_INTERNET_MASK  (IFLAG_IGNORE_CERT_CN_INVALID    | IFLAG_IGNORE_CERT_DATE_INVALID  |  IFLAG_IGNORE_REDIRECT_TO_HTTPS  | IFLAG_IGNORE_REDIRECT_TO_HTTP   )

#define SECURITY_SET_MASK       SECURITY_INTERNET_MASK

#define IFLAGS_MASK     (IFLAG_RELOAD | IFLAG_RAW_DATA | IFLAG_EXISTING_CONNECT | IFLAG_ASYNC | IFLAG_PASSIVE | IFLAG_NO_CACHE_WRITE | IFLAG_MAKE_PERSISTENT | IFLAG_OFFLINE | IFLAG_SECURE | IFLAG_KEEP_CONNECTION | IFLAG_NO_AUTO_REDIRECT | IFLAG_READ_PREFETCH | IFLAG_NO_COOKIES | IFLAG_NO_AUTH | SECURITY_INTERNET_MASK | IFLAG_TRANSFER_ASCII | IFLAG_TRANSFER_BINARY | IFLAG_RESYNCHRONIZE | IFLAG_MUST_CACHE_REQUEST | IFLAG_HYPERLINK | IFLAG_NO_UI )

#define IOPTIONS_MASK   (!IFLAGS_MASK)

//
// INTERNET_NO_CALLBACK - if this value is presented as the dwContext parameter
// then no call-backs will be made for that API
//

#define INTERNET_NO_CALLBACK            0

//
// structures/types
//

//
// INTERNET_SCHEME - enumerated URL scheme type
//

#define    INTERNET_SCHEME_PARTIAL  -2
#define    INTERNET_SCHEME_UNKNOWN  -1
#define    INTERNET_SCHEME_DEFAULT  0
#define    INTERNET_SCHEME_FTP      1
#define    INTERNET_SCHEME_GOPHER   2
#define    INTERNET_SCHEME_HTTP     3
#define    INTERNET_SCHEME_HTTPS    4
#define    INTERNET_SCHEME_FILE     5
#define    INTERNET_SCHEME_NEWS     6
#define    INTERNET_SCHEME_MAILTO   7
#define    INTERNET_SCHEME_SOCKS    8
#define    INTERNET_SCHEME_FIRST    INTERNET_SCHEME_FTP
#define    INTERNET_SCHEME_LAST     INTERNET_SCHEME_SOCKS

#define INTERNET_SCHEME   Word
#define LPINTERNET_SCHEME *Word

//
// INTERNET_ASYNC_RESULT - this structure is returned to the application via
// the callback with INTERNET_STATUS_REQUEST_COMPLETE. It is not sufficient to
// just return the result of the async operation. If the API failed then the
// app cannot call GetLastError() because the thread context will be incorrect.
// Both the value returned by the async API and any resultant error code are
// made available. The app need not check dwError if dwResult indicates that
// the API succeeded (in this case dwError will be ERROR_SUCCESS)
//

struct INTERNET_ASYNC_RESULT {

    //
    // dwResult - the HINTERNET, DWORD or BOOL return code from an async API
    //

    INT dwResult;

    //
    // dwError - the error code if the API failed
    //

    INT dwError;
}
#define LPINTERNET_ASYNC_RESULT   Pointer

//
// INTERNET_PREFETCH_STATUS -
//

struct INTERNET_PREFETCH_STATUS {

    //
    // dwStatus - status of download. See INTERNET_PREFETCH_ flags
    //

    INT dwStatus;

    //
    // dwSize - size of file downloaded so far
    //

    INT dwSize;
}
#define LPINTERNET_PREFETCH_STATUS Pointer

//
// INTERNET_PREFETCH_STATUS - dwStatus values
//

#define INTERNET_PREFETCH_PROGRESS  0
#define INTERNET_PREFETCH_COMPLETE  1
#define INTERNET_PREFETCH_ABORTED   2

//
// INTERNET_PROXY_INFO - structure supplied with INTERNET_OPTION_PROXY to get/
// set proxy information on a InternetOpen() handle
//

struct INTERNET_PROXY_INFO{

    //
    // dwAccessType - INTERNET_OPEN_TYPE_DIRECT, INTERNET_OPEN_TYPE_PROXY, or
    // INTERNET_OPEN_TYPE_PRECONFIG (set only)
    //

    INT dwAccessType;

    //
    // lpszProxy - proxy server list
    //

    INT lpszProxy;

    //
    // lpszProxyBypass - proxy bypass list
    //

    INT lpszProxyBypass;
}
#define LPINTERNET_PROXY_INFO Pointer


//
// INTERNET_VERSION_INFO - version information returned via
// InternetQueryOption(..., INTERNET_OPTION_VERSION, ...)
//

struct INTERNET_VERSION_INFO {
    INT dwMajorVersion;
    INT dwMinorVersion;
}
#define LPINTERNET_VERSION_INFO Pointer;

//
// URL_COMPONENTS - the constituent parts of an URL. Used in InternetCrackUrl()
// and InternetCreateUrl()
//
// For InternetCrackUrl(), if a pointer field and its corresponding length field
// are both 0 then that component is not returned; If the pointer field is NULL
// but the length field is not zero, then both the pointer and length fields are
// returned; if both pointer and corresponding length fields are non-zero then
// the pointer field points to a buffer where the component is copied. The
// component may be un-escaped, depending on dwFlags
//
// For InternetCreateUrl(), the pointer fields should be NULL if the component
// is not required. If the corresponding length field is zero then the pointer
// field is the address of a zero-terminated string. If the length field is not
// zero then it is the string length of the corresponding pointer field
//

struct URL_COMPONENTSA {
    INT       dwStructSize;       // size of this structure. Used in version check
    INT       lpszScheme;         // pointer to scheme name
    INT       dwSchemeLength;     // length of scheme name
    INTERNET_SCHEME   nScheme;    // enumerated scheme type (if known)
    INT       lpszHostName;       // pointer to host name
    INT       dwHostNameLength;   // length of host name
    INTERNET_PORT   nPort;        // converted port number
    INT       lpszUserName;       // pointer to user name
    INT       dwUserNameLength;   // length of user name
    INT       lpszPassword;       // pointer to password
    INT       dwPasswordLength;   // length of password
    INT       lpszUrlPath;        // pointer to URL-path
    INT       dwUrlPathLength;    // length of URL-path
    INT       lpszExtraInfo;      // pointer to extra information (e.g. ?foo or #foo)
    INT       dwExtraInfoLength;  // length of extra information
}
#define LPURL_COMPONENTSA Pointer


//
// prototypes
//

import
INT
InternetTimeFromSystemTime(
    Pointer pst,          // input GMT time
    DWORD dwRFC,          // RFC format
    *ASCIIZ lpszTime,     // output string buffer
    DWORD cbTime          // output buffer size
    ) wininet "InternetTimeFromSystemTime";

//
// constants for InternetTimeFromSystemTime
//

#define INTERNET_RFC1123_FORMAT     0
#define INTERNET_RFC1123_BUFSIZE   30

import
INT
InternetTimeToSystemTime(
    *ASCIIZ lpszTime,         // NULL terminated string
    Pointer pst,              // output in GMT time
    DWORD dwReserved
    ) wininet "InternetTimeToSystemTime";

import
INT
InternetDebugGetLocalTime(
    Pointer pstLocalTime,
    *DWORD  pdwReserved
) wininet "InternetDebugGetLocalTime";

import
INT
InternetCrackUrlA(
    *ASCIIZ lpszUrl,
    DWORD dwUrlLength,
    DWORD dwFlags,
    LPURL_COMPONENTSA lpUrlComponents
    ) wininet "InternetCrackUrlA";

import
INT
InternetCreateUrlA(
    LPURL_COMPONENTSA lpUrlComponents,
    DWORD dwFlags,
    *ASCIIZ lpszUrl,
    *DWORD lpdwUrlLength
    ) wininet "InternetCreateUrlA";

import
INT
InternetCanonicalizeUrlA(
    ASCIIZ lpszUrl,
    *ASCIIZ lpszBuffer,
    *DWORD lpdwBufferLength,
    DWORD dwFlags
    ) wininet "InternetCanonicalizeUrlA";

import
INT
InternetCombineUrlA(
    ASCIIZ lpszBaseUrl,
    ASCIIZ lpszRelativeUrl,
    *ASCIIZ lpszBuffer,
    *DWORD lpdwBufferLength,
    DWORD dwFlags
    ) wininet "InternetCombineUrlA";

//
// flags for InternetCrackUrl() and InternetCreateUrl()
//

#define ICU_ESCAPE      0x80000000  // (un)escape URL characters
#define ICU_USERNAME    0x40000000  // use internal username & password

//
// flags for InternetCanonicalizeUrl() and InternetCombineUrl()
//

#define ICU_NO_ENCODE   0x20000000  // Don't convert unsafe characters to escape sequence
#define ICU_DECODE      0x10000000  // Convert %XX escape sequences to characters
#define ICU_NO_META     0x08000000  // Don't convert .. etc. meta path sequences
#define ICU_ENCODE_SPACES_ONLY 0x04000000  // Encode spaces only
#define ICU_BROWSER_MODE 0x02000000 // Special encode/decode rules for browser

import HINTERNET InternetOpenA(
    ASCIIZ lpszAgent,
    DWORD dwAccessType,
    DWORD lpszProxy,
    DWORD lpszProxyBypass,
    DWORD dwFlags
    ) wininet "InternetOpenA";

#define INTERNET_OPEN_TYPE_PRECONFIG    0   // use registry configuration
#define INTERNET_OPEN_TYPE_DIRECT       1   // direct to net
#define INTERNET_OPEN_TYPE_PROXY        3   // via named proxy

#define PRE_CONFIG_INTERNET_ACCESS  INTERNET_OPEN_TYPE_PRECONFIG
#define LOCAL_INTERNET_ACCESS       INTERNET_OPEN_TYPE_DIRECT
#define GATEWAY_INTERNET_ACCESS     2   // Internet via gateway
#define CERN_PROXY_INTERNET_ACCESS  INTERNET_OPEN_TYPE_PROXY

import
INT
InternetCloseHandle(
    HINTERNET hInternet
    ) wininet "InternetCloseHandle";

import
HINTERNET
InternetConnectA(
    HINTERNET hInternet,
    ASCIIZ lpszServerName,
    INTERNET_PORT nServerPort,
    ASCIIZ lpszUserName,
    ASCIIZ lpszPassword,
    DWORD dwService,
    DWORD dwFlags,
    DWORD dwContext
    ) wininet "InternetConnectA";

//
// service types for InternetConnect()
//

#define INTERNET_SERVICE_FTP    1
#define INTERNET_SERVICE_GOPHER 2
#define INTERNET_SERVICE_HTTP   3

import
HINTERNET
InternetOpenUrlA(
    HINTERNET hInternet,
    ASCIIZ lpszUrl,
    ASCIIZ lpszHeaders,
    DWORD dwHeadersLength,
    DWORD dwFlags,
    DWORD dwContext
    ) wininet "InternetOpenUrlA";


import
INT
InternetReadFile(
    HINTERNET hFile,
    Pointer lpBuffer,
    DWORD dwNumberOfBytesToRead,
    *DWORD lpdwNumberOfBytesRead
    ) wininet "InternetReadFile";

import
DWORD
InternetSetFilePointer(
    HINTERNET hFile,
    INT lDistanceToMove,
    Pointer pReserved,
    DWORD dwMoveMethod,
    DWORD dwContext
    ) wininet "InternetSetFilePointer";

import
INT
InternetWriteFile(
    HINTERNET hFile,
    Pointer lpBuffer,
    DWORD dwNumberOfBytesToWrite,
    *DWORD lpdwNumberOfBytesWritten
    ) wininet "InternetWriteFile";

import
INT
InternetQueryDataAvailable(
    HINTERNET hFile,
    *DWORD lpdwNumberOfBytesAvailable,
    DWORD dwFlags,
    DWORD dwContext
    ) wininet "InternetQueryDataAvailable";

import
INT
InternetFindNextFileA(
    HINTERNET hFind,
    Pointer lpvFindData
    ) wininet "InternetFindNextFileA";

import
INT
InternetQueryOptionA(
    HINTERNET hInternet,
    DWORD dwOption,
    Pointer lpBuffer,
    *DWORD lpdwBufferLength
    ) wininet "InternetQueryOptionA";

import
INT
InternetSetOptionA(
    HINTERNET hInternet,
    DWORD dwOption,
    Pointer lpBuffer,
    DWORD dwBufferLength
    ) wininet "InternetSetOptionA";

import
INT
InternetSetOptionExA(
    HINTERNET hInternet ,
    DWORD dwOption,
    Pointer lpBuffer,
    DWORD dwBufferLength,
    DWORD dwFlags
    ) wininet "InternetSetOptionExA";

//
// flags for InternetSetOptionEx()
//

#define ISO_GLOBAL      0x00000001  // modify option globally
#define ISO_REGISTRY    0x00000002  // write option to registry (where applicable)

#define ISO_VALID_FLAGS (ISO_GLOBAL | ISO_REGISTRY)

//
// options manifests for Internet{Query|Set}Option
//

#define IOPTION_CALLBACK                1
#define IOPTION_CONNECT_TIMEOUT         2
#define IOPTION_CONNECT_RETRIES         3
#define IOPTION_CONNECT_BACKOFF         4
#define IOPTION_SEND_TIMEOUT            5
#define IOPTION_CONTROL_SEND_TIMEOUT    IOPTION_SEND_TIMEOUT
#define IOPTION_RECEIVE_TIMEOUT         6
#define IOPTION_CONTROL_RECEIVE_TIMEOUT IOPTION_RECEIVE_TIMEOUT
#define IOPTION_DATA_SEND_TIMEOUT       7
#define IOPTION_DATA_RECEIVE_TIMEOUT    8
#define IOPTION_HANDLE_TYPE             9
#define IOPTION_CONTEXT_VALUE           10
#define IOPTION_LISTEN_TIMEOUT          11
#define IOPTION_READ_BUFFER_SIZE        12
#define IOPTION_WRITE_BUFFER_SIZE       13

#define IOPTION_ASYNC_ID                15
#define IOPTION_ASYNC_PRIORITY          16

#define IOPTION_PARENT_HANDLE           21
#define IOPTION_KEEP_CONNECTION         22
#define IOPTION_REQUEST_FLAGS           23
#define IOPTION_EXTENDED_ERROR          24

#define IOPTION_OFFLINE_MODE            26
#define IOPTION_CACHE_STREAM_HANDLE     27
#define IOPTION_USERNAME                28
#define IOPTION_PASSWORD                29
#define IOPTION_ASYNC                   30
#define IOPTION_SECURITY_FLAGS          31
#define IOPTION_SECURITY_CERTIFICATE_STRUCT    32
#define IOPTION_DATAFILE_NAME           33
#define IOPTION_URL                     34
#define IOPTION_SECURITY_CERTIFICATE    35
#define IOPTION_SECURITY_KEY_BITNESS    36
#define IOPTION_REFRESH                 37
#define IOPTION_PROXY                   38
#define IOPTION_SETTINGS_CHANGED        39
#define IOPTION_VERSION                 40
#define IOPTION_USER_AGENT              41

#define INTERNET_FIRST_OPTION                   IOPTION_CALLBACK
#define INTERNET_LAST_OPTION                    IOPTION_USER_AGENT

//
// Internet API error returns
//
#define INTERNET_ERROR_BASE                     12000

#define ERRORI_OUT_OF_HANDLES                   12001
#define ERRORI_TIMEOUT                       		12002
#define ERRORI_EXTENDED_ERROR                		12003
#define ERRORI_INTERNAL_ERROR                12004
#define ERRORI_INVALID_URL                   12005
#define ERRORI_UNRECOGNIZED_SCHEME           12006
#define ERRORI_NAME_NOT_RESOLVED             12007
#define ERRORI_PROTOCOL_NOT_FOUND            12008
#define ERRORI_INVALID_OPTION                12009
#define ERRORI_BAD_OPTION_LENGTH             12010
#define ERRORI_OPTION_NOT_SETTABLE           12011
#define ERRORI_SHUTDOWN                      12012
#define ERRORI_INCORRECT_USER_NAME           12013
#define ERRORI_INCORRECT_PASSWORD            12014
#define ERRORI_LOGIN_FAILURE                 12015
#define ERRORI_INVALID_OPERATION             12016
#define ERRORI_OPERATION_CANCELLED           12017
#define ERRORI_INCORRECT_HANDLE_TYPE         12018
#define ERRORI_INCORRECT_HANDLE_STATE        12019
#define ERRORI_NOT_PROXY_REQUEST             12020
#define ERRORI_REGISTRY_VALUE_NOT_FOUND      12021
#define ERRORI_BAD_REGISTRY_PARAMETER        12022
#define ERRORI_NO_DIRECT_ACCESS              12023
#define ERRORI_NO_CONTEXT                    12024
#define ERRORI_NO_CALLBACK                   12025
#define ERRORI_REQUEST_PENDING               12026
#define ERRORI_INCORRECT_FORMAT              12027
#define ERRORI_ITEM_NOT_FOUND                12028
#define ERRORI_CANNOT_CONNECT                12029
#define ERRORI_CONNECTION_ABORTED            12030
#define ERRORI_CONNECTION_RESET              12031
#define ERRORI_FORCE_RETRY                   12032
#define ERRORI_INVALID_PROXY_REQUEST         12033

#define ERRORI_HANDLE_EXISTS                 12036
#define ERRORI_SEC_CERT_DATE_INVALID         12037
#define ERRORI_SEC_CERT_CN_INVALID           12038
#define ERRORI_HTTP_TO_HTTPS_ON_REDIR        12039
#define ERRORI_HTTPS_TO_HTTP_ON_REDIR        12040
#define ERRORI_MIXED_SECURITY                12041
#define ERRORI_CHG_POST_IS_NON_SECURE        12042
#define ERRORI_POST_IS_NON_SECURE            12043

//FTP API errors }

#define ERRORF_TRANSFER_IN_PROGRESS            12110
#define ERRORF_DROPPED                         12111


// gopher API errors

#define ERRORG_PROTOCOL_ERROR                  12130
#define ERRORG_NOT_FILE                        12131
#define ERRORG_DATA_ERROR                      12132
#define ERRORG_END_OF_DATA                     12133
#define ERRORG_INVALID_LOCATOR                 12134
#define ERRORG_INCORRECT_LOCATOR_TYPE          12135
#define ERRORG_NOT_GOPHER_PLUS                 12136
#define ERRORG_ATTRIBUTE_NOT_FOUND             12137
#define ERRORG_UNKNOWN_LOCATOR                 12138

//HTTP API errors

#define ERRORH_HEADER_NOT_FOUND                12150
#define ERRORH_DOWNLEVEL_SERVER                12151
#define ERRORH_INVALID_SERVER_RESPONSE         12152
#define ERRORH_INVALID_HEADER                  12153
#define ERRORH_INVALID_QUERY_REQUEST           12154
#define ERRORH_HEADER_ALREADY_EXISTS           12155
#define ERRORH_REDIRECT_FAILED                 12156

#define INTERNET_ERROR_LAST                    ERROR_HTTP_REDIRECT_FAILED
//
// values for IOPTION_PRIORITY
//

#define INTERNET_PRIORITY_FOREGROUND

//
// handle types
//

#define IHANDLE_TYPE_INTERNET           1
#define IHANDLE_TYPE_CONNECT_FTP        2
#define IHANDLE_TYPE_CONNECT_GOPHER     3
#define IHANDLE_TYPE_CONNECT_HTTP       4
#define IHANDLE_TYPE_FTP_FIND           5
#define IHANDLE_TYPE_FTP_FIND_HTML      6
#define IHANDLE_TYPE_FTP_FILE           7
#define IHANDLE_TYPE_FTP_FILE_HTML      8
#define IHANDLE_TYPE_GOPHER_FIND        9
#define IHANDLE_TYPE_GOPHER_FIND_HTML   10
#define IHANDLE_TYPE_GOPHER_FILE        11
#define IHANDLE_TYPE_GOPHER_FILE_HTML   12
#define IHANDLE_TYPE_HTTP_REQUEST       13

//
// values for IOPTION_SECURITY_FLAGS
//

#define SFLAG_SECURE                    0x00000001 // can query only
#define SFLAG_SSL                       0x00000002
#define SFLAG_SSL3                      0x00000004
#define SFLAG_PCT                       0x00000008
#define SFLAG_PCT4                      0x00000010
#define SFLAG_IETFSSL4                  0x00000020

#define SFLAG_40BIT                     0x10000000
#define SFLAG_128BIT                    0x20000000
#define SFLAG_56BIT                     0x40000000
#define SFLAG_UNKNOWNBIT                0x80000000
#define SFLAG_NORMALBITNESS             SFLAG_40BIT

#define SFLAG_IGNORE_CERT_CN_INVALID    IFLAG_IGNORE_CERT_CN_INVALID
#define SFLAG_IGNORE_CERT_DATE_INVALID  IFLAG_IGNORE_CERT_DATE_INVALID
#define SFLAG_IGNORE_REDIRECT_TO_HTTPS  IFLAG_IGNORE_REDIRECT_TO_HTTPS
#define SFLAG_IGNORE_REDIRECT_TO_HTTP   IFLAG_IGNORE_REDIRECT_TO_HTTP

import
INT
InternetGetLastResponseInfoA(
    *DWORD lpdwError,
    *ASCIIZ lpszBuffer,
    *DWORD lpdwBufferLength
    ) wininet "InternetGetLastResponseInfoA";

//
// callback function for InternetSetStatusCallback
//

  // We need to make a macro callback for this.
//typedef
//VOID
//(CALLBACK * INTERNET_STATUS_CALLBACK)(
//    IN HINTERNET hInternet,
//    IN DWORD dwContext,
//    IN DWORD dwInternetStatus,
//    IN Pointer lpvStatusInformation OPTIONAL,
//    IN DWORD dwStatusInformationLength
//    );

//typedef INTERNET_STATUS_CALLBACK * LPINTERNET_STATUS_CALLBACK;

//INTERNETAPI
//INTERNET_STATUS_CALLBACK
//import
//InternetSetStatusCallback(
//    IN HINTERNET hInternet,
//    IN INTERNET_STATUS_CALLBACK lpfnInternetCallback
//    );

////
//// status manifests for Internet status callback
////

#define ISTATUS_RESOLVING_NAME          10
#define ISTATUS_NAME_RESOLVED           11
#define ISTATUS_CONNECTING_TO_SERVER    20
#define ISTATUS_CONNECTED_TO_SERVER     21
#define ISTATUS_SENDING_REQUEST         30
#define ISTATUS_REQUEST_SENT            31
#define ISTATUS_RECEIVING_RESPONSE      40
#define ISTATUS_RESPONSE_RECEIVED       41
#define ISTATUS_CTL_RESPONSE_RECEIVED   42
#define ISTATUS_PREFETCH                43
#define ISTATUS_CLOSING_CONNECTION      50
#define ISTATUS_CONNECTION_CLOSED       51
#define ISTATUS_HANDLE_CREATED          60
#define ISTATUS_HANDLE_CLOSING          70
#define ISTATUS_REQUEST_COMPLETE        100
#define ISTATUS_REDIRECT                110

//
// if the following value is returned by InternetSetStatusCallback, then
// probably an invalid (non-code) address was supplied for the callback
//

#define INTERNET_INVALID_STATUS_CALLBACK        ((INTERNET_STATUS_CALLBACK)(-1L))

//
// FTP
//

//
// manifests
//

#define FTP_TRANSFER_TYPE_UNKNOWN   0x00000000
#define FTP_TRANSFER_TYPE_ASCII     0x00000001
#define FTP_TRANSFER_TYPE_BINARY    0x00000002

#define FTP_TRANSFER_TYPE_MASK      (FTP_TRANSFER_TYPE_ASCII | FTP_TRANSFER_TYPE_BINARY)

//
// prototypes
//

import
HINTERNET
FtpFindFirstFileA(
    HINTERNET hConnect,
    ASCIIZ lpszSearchFile,
    LPWIN32_FIND_DATA lpFindFileData,
    DWORD dwFlags,
    DWORD dwContext
    ) wininet "FtpFindFirstFileA";

import
INT
FtpGetFileA(
    HINTERNET hConnect,
    ASCIIZ lpszRemoteFile,
    ASCIIZ lpszNewFile,
    INT fFailIfExists,
    DWORD dwFlagsAndAttributes,
    DWORD dwFlags,
    DWORD dwContext
    ) wininet "FtpGetFileA";

import
INT
FtpPutFileA(
    HINTERNET hConnect,
    ASCIIZ lpszLocalFile,
    ASCIIZ lpszNewRemoteFile,
    DWORD dwFlags,
    DWORD dwContext
    ) wininet "FtpPutFileA";

import
INT
FtpDeleteFileA(
    HINTERNET hConnect,
    ASCIIZ lpszFileName
    ) wininet "FtpDeleteFileA";

import
INT
FtpRenameFileA(
    HINTERNET hConnect,
    ASCIIZ lpszExisting,
    ASCIIZ lpszNew
    ) wininet "FtpRenameFileA";

import
HINTERNET
FtpOpenFileA(
    HINTERNET hConnect,
    ASCIIZ lpszFileName,
    DWORD dwAccess,
    DWORD dwFlags,
    DWORD dwContext
    ) wininet "FtpOpenFileA";

import
INT
FtpCreateDirectoryA(
    HINTERNET hConnect,
    ASCIIZ lpszDirectory
    ) wininet "FtpCreateDirectoryA";

import
INT
FtpRemoveDirectoryA(
    HINTERNET hConnect,
    ASCIIZ lpszDirectory
    ) wininet "FtpRemoveDirectoryA";

import
INT
FtpSetCurrentDirectoryA(
    HINTERNET hConnect,
    ASCIIZ lpszDirectory
    ) wininet "FtpSetCurrentDirectoryA";

import
INT
FtpGetCurrentDirectoryA(
    HINTERNET hConnect,
    *ASCIIZ lpszCurrentDirectory,
    *DWORD lpdwCurrentDirectory
    ) wininet "FtpGetCurrentDirectoryA";

import
INT
FtpCommandA(
    HINTERNET hConnect,
    INT fExpectResponse,
    DWORD dwFlags,
    ASCIIZ lpszCommand,
    DWORD dwContext
    ) wininet "FtpCommandA";

#endif // !defined(_wininet_)